HttpClientBuilder

Struct HttpClientBuilder 

pub struct HttpClientBuilder { /* private fields */ }
HTTP client builder for configuring proxy and TLS settings

Implementations

Source

impl HttpClientBuilder

pub fn danger_accept_invalid_certs(self, accept: bool) -> Self

Accept invalid TLS certificates

pub fn no_redirects(self) -> Self

Disable automatic HTTP redirect following

pub fn proxy(self, url: Url) -> Self

Set an HTTP proxy URL.

The bitreq backend supports HTTP proxy URLs only. SOCKS proxy schemes such as socks5h require building this crate with the reqwest feature.

pub fn proxy_with_matcher(self, url: Url, pattern: &str) -> Response<Self>

Set an HTTP proxy URL with a host pattern matcher.

The bitreq backend supports HTTP proxy URLs only. SOCKS proxy schemes such as socks5h require building this crate with the reqwest feature.

pub fn build(self) -> Response<HttpClient>

Build the HTTP client