pub struct RawResponse { /* private fields */ }Expand description
Raw HTTP response with status code and body access
Implementations
Sourceimpl RawResponse
impl RawResponse
Sourcepub fn is_success(&self) -> bool
pub fn is_success(&self) -> bool
Check if the response status is a success (2xx)
Sourcepub fn is_client_error(&self) -> bool
pub fn is_client_error(&self) -> bool
Check if the response status is a client error (4xx)
Sourcepub fn is_server_error(&self) -> bool
pub fn is_server_error(&self) -> bool
Check if the response status is a server error (5xx)
Sourcepub async fn json<T: DeserializeOwned>(self) -> Response<T>
pub async fn json<T: DeserializeOwned>(self) -> Response<T>
Get the response body as JSON