RawResponse

Struct RawResponse 

pub struct RawResponse { /* private fields */ }
Raw HTTP response with status code and body access

Implementations

Source

impl RawResponse

pub fn new(status: u16, body: Vec<u8>) -> Self

Create a new RawResponse from status and body bytes

pub fn status(&self) -> u16

Get the HTTP status code

pub fn is_success(&self) -> bool

Check if the response status is a success (2xx)

pub fn is_client_error(&self) -> bool

Check if the response status is a client error (4xx)

pub fn is_server_error(&self) -> bool

Check if the response status is a server error (5xx)

pub fn body_lossy(&self) -> String

Response body as lossy UTF-8 string

pub fn json_or_status_error<T: DeserializeOwned>(self) -> Response<T>

Deserialize JSON from a successful response, or return HttpError::Status

pub async fn text(self) -> Response<String>

Get the response body as text

pub async fn json<T: DeserializeOwned>(self) -> Response<T>

Get the response body as JSON

pub async fn bytes(self) -> Response<Vec<u8>>

Get the response body as bytes